@@ -42,6 +42,30 @@ BEGIN { $fields = {
 	"payment_details" => new WWW::Shopify::Field::Freeform(),
 	"response_code" => new WWW::Shopify::Field::String(),
 	"response_reason_code" =>  new WWW::Shopify::Field::String(),
+	# Shopify payments.
+	"object" => new WWW::Shopify::Field::String(),
+	"created" => new WWW::Shopify::Field::Int(),
+	"livemode" => new WWW::Shopify::Field::Boolean(),
+	"paid" => new WWW::Shopify::Field::Boolean(),
+	"currency" => new WWW::Shopify::Field::String(),
+	"refunded" => new WWW::Shopify::Field::Freeform(),
+	"card" => new WWW::Shopify::Field::Freeform(),
+	"captured" => new WWW::Shopify::Field::Boolean(),
+	"refunds" => new WWW::Shopify::Field::Freeform(),
+	"balance_transaction" => new WWW::Shopify::Field::Freeform(),
+	"failure_message" => new WWW::Shopify::Field::Freeform(),
+	"failure_code" => new WWW::Shopify::Field::Freeform(),
+	"amount_refunded" => new WWW::Shopify::Field::Int(),
+	"customer" => new WWW::Shopify::Field::Freeform(),
+	"invoice" => new WWW::Shopify::Field::Freeform(),
+	"description" => new WWW::Shopify::Field::String(),
+	"dispute" => new WWW::Shopify::Field::Freeform(),
+	"metadata" => new WWW::Shopify::Field::Freeform(),
+	"statement_description" => new WWW::Shopify::Field::Freeform(),
+	"fraud_details" => new WWW::Shopify::Field::Freeform(),
+	"receipt_email" => new WWW::Shopify::Field::Freeform(),
+	"receipt_number" => new WWW::Shopify::Field::Freeform(),
+	"shipping" => new WWW::Shopify::Field::Freeform(),
 }; }
 
 eval(__PACKAGE__->generate_accessors); die $@ if $@;
